@@ -124,7 +124,7 @@ class Sequence(Generic[T], Iterable[T]):
         return self.map(transform).filter_not_none()
     
 
-    def parallel_map(self, transform: Callable[[T], R], max_workers: Optional[int]=None) -> Sequence[R]:
+    def parallel_map(self, transform: Callable[[T], R], max_workers: Optional[int]=None, chunksize: int=1, executor: ParallelMappingSequence.Executor='Thread') -> Sequence[R]:
         """
          Returns a Sequence containing the results of applying the given [transform] function
          to each element in the original Sequence.
@@ -139,7 +139,7 @@ class Sequence(Generic[T], Iterable[T]):
         >>> it(lst).parallel_map(lambda x: x['age'], max_workers=2)
         [12, 13]
         """
-        return ParallelMappingSequence(self, transform, max_workers)
+        return ParallelMappingSequence(self, transform, max_workers, chunksize, executor)
 
     def find(self, predicate: Callable[[T], bool]) -> Optional[T]:
         """
@@ -1298,7 +1298,7 @@ class Sequence(Generic[T], Iterable[T]):
             action(i)
         return self
     
-    def parallel_on_each(self, action: Callable[[T], None], max_workers: Optional[int]=None) -> Sequence[T]:
+    def parallel_on_each(self, action: Callable[[T], None], max_workers: Optional[int]=None, chunksize: int=1, executor: ParallelMappingSequence.Executor='Thread' ) -> Sequence[T]:
         """
          Invokes [action] function on each element of the given Sequence.
 
@@ -1316,7 +1316,7 @@ class Sequence(Generic[T], Iterable[T]):
         b
         c
         """
-        for _ in ParallelMappingSequence(self, action, max_workers):
+        for _ in ParallelMappingSequence(self, action, max_workers, chunksize, executor):
             pass
         return self
     
@@ -1704,28 +1704,50 @@ class MappingSequence(Sequence[R]):
 
 
 class ParallelMappingSequence(Sequence[R]):
-    def __init__(self, iterable: Iterable[Sequence[T]], transformer: Callable[[T], R], max_workers: Optional[int]=None) -> None:
+    Executor = Literal['Thread', 'Process']
+
+    def __init__(
+            self, 
+            iterable: Iterable[Sequence[T]], 
+            transformer: Callable[[T], R], 
+            max_workers: Optional[int]=None, 
+            chunksize: int=1,
+            executor: Executor = 'Thread') -> None:
+
         super().__init__(iterable)
         self._transformer = transformer
         self._max_workers = max_workers
+        self._executor = executor
+        self._chunksize = chunksize
     
     def __do_iter__(self) -> Iterator[R]:
-        from concurrent.futures import ThreadPoolExecutor
         import os
 
+        def create_executor(max_workers: int, ):
+            if self._executor == 'Process':
+                from concurrent.futures import ProcessPoolExecutor
+                return ProcessPoolExecutor(max_workers=max_workers)
+            else:
+                from concurrent.futures import ThreadPoolExecutor
+                return ThreadPoolExecutor(max_workers=max_workers, thread_name_prefix='PyIter worker')
+
         size = len(self._iter)
+        chunksize = self._chunksize
         max_workers = self._max_workers or min(32, (os.cpu_count() or 1) + 4)
+        batch_count = -1 * (-size // chunksize)
+        max_workers = min(max_workers, batch_count)
 
-        chunksize = size // max_workers
+        batch_size = max_workers * chunksize
 
-        if chunksize < 2:
-            with ThreadPoolExecutor(max_workers=size if size < max_workers else max_workers, thread_name_prefix='PyIter worker') as executor:
-                yield from executor.map(self._transformer, self._iter)
-                    
+        if batch_size < size:
+            for batch in it(self._iter).chunked(batch_size):
+                with create_executor(max_workers) as executor:
+                    yield from executor.map(self._transformer, batch, chunksize=chunksize)
         else:
-            for batch in it(self._iter).chunked(chunksize):
-                with ThreadPoolExecutor(max_workers=max_workers, thread_name_prefix='PyIter worker') as executor:
-                    yield from executor.map(self._transformer, batch)
+            with create_executor(max_workers) as executor:
+                yield from executor.map(self._transformer, self._iter, chunksize=chunksize)
+
+    
 
 
 class IndexedValue(Generic[T]):
